<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Klicka för att återgå till applikationen</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Hämtningar</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Rensa</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 objekt</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulär</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Filnamn</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Försök igen</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicera Podcast på YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Författare</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tavla</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Nät</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Pekpenna</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Bakgrund</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Ändra bakgrund</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ångra</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Gör om inmatning</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Föregående sida</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Rulla uppåt</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Nästa sida</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Rulla nedåt</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Hantera dokument</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Liten linje</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Medium linje</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>stor linje</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Sudd</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Litet sudd</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Medium sudd</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Stort sudd</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Färg</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Backa</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Framåt</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Uppdatera aktuell sida</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Hem</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Ladda startsida</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Bokmärken</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Visa bokmärken</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Lägg till bokmärke</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Lägg till bokmärke</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Visa tavla</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Radera innehåll</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Visa inställningar</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotek</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Visa bibliotek</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Visa skrivbord</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Visa datorns skrivbord</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Förstora</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zooma in</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Förminska</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zooma ut</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Ny mapp</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Skapa ny mapp</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nytt dokument</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Skapa nytt dokument</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importera ett dokument</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportera ett dokument</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Öppna i tavla</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Öppna sida i tavla</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicera</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplicera markerat innehåll</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Radera markerat innehåll</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Lägg till i arbetsdokumentet</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Lägg till markerat innehåll i öppet dokument</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Lägg till innehåll till dokument</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Byt namn på innehåll</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Verktyg</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Visa verktyg</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multi skärm</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Bred storlek (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Använd bred dokumentstorlek (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Normal storlek (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Använd normal dokumentstorlek (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Anpassad storlek</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Använd anpassad dokumentstorlek</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Sluta ladda</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Sluta ladda web sida</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Viloläge</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Sätt presentation i viloläge</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuellt tangentbord</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Visa virtuellt tangentbord</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Enkel ljus bakgrund</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Ljus</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Rutig ljus bakgrund</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Enkel mörk bakgrund</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Mörk</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Rutig mörk bakgrund</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Spela in presentation till video</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Spela in</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Starta skärminspelning</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Radra objekt</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Radera alla objekt</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Radera kommetarer</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Radera alla kommentarer</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Rensa sida</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Rensa alla element</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Kommentera dokument</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Radera kommetar</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markör</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Markera</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Väljare</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Markera och ändra objekt</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Hand</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Rulla sida</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laser pekare</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuellt laserpekare</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Rita linjer</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Skriv text</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Fånga</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Fånga en del av skärmen</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Lägg till aktuell sida</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Lägg objekt till aktuell sida</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Lägg till ny sida</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Lägg objekt till ny sida</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Lägg till bibliotek</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Lägg objekt till bibliotek</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Sidor</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Skapa ny sida</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Ny sida</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplicera sida</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplicera aktuell sida</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importera sida</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importera extern sida</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paus</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pausa inspelning av podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Anpassa Podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Anpassa inspelning av Podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Lagra flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Lagra flash innehål</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Lagra web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Lagra webinnehål</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Anpassa fånga</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Fönster fånga</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Fånga ett fönster</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Inbäddat webinnehåll</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Fånga inbäddat webinnehåll</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Visa på skärm</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Visa primärskärm på visningsskärm</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Radera alla kommentarer</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>utbMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importera utbMedia simulation</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Kontrollera uppdatering</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>Öppna Sankoré</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Lämna öppen Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Göm öppen Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Göm öppen Sankoré applikation</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interagera med objekt</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Radera bakgrund</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Ta bort bakgrund</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Inloggning krävs</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy verifiering</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Anslut till proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Sapara användarnamn och lösenord för framtida användning</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Element ID=</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Innehållet stöds inte i destinationsformatet</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Ta bort sida</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Är du säker på att du vill ta bort 1 sida från det valda dokumentet &apos;%0&apos;?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Storlek på sida</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Nät</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Ny uppdatering tillgänglig, vill du besöka web sidan?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Inga uppdateringar tillgängliga</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Uppdateringar tillgängliga</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uppdatera</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Hämtning av innehåll %1 misslyckades</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Hämtning avslutad</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Okänd verktygstyp %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Okänd innehållstyp %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Lägg till objekt</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Alla stöds (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Radera sida %1 från dokument</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Sida %1 raderad</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Lägg till fil åtgärd misslyckad: filkopieringsfel</translation>
    </message>
    <message>
        <source>Group</source>
        <translatorcomment>Verb our a noun? Next segement is Ungorup = verb. If &quot;Group&quot; is a verb it should be &quot;Gruppera&quot; in sv.</translatorcomment>
        <translation>Grupp</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Avgruppera</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Färg</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Fel vid lägg bild bibliotek </translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>FångadBild</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Cacheinställningar</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Färg:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Form:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Fånga en del av skärmen</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Fånga skärmen</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Visa pekpennans palett</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Visa taval på den sekundära skärmen</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Visa skrivbordet på den sekundära skärmen</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Ny mapp</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Sida %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Lägg till mapp med bilder</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Lägg till bilder</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Lägg till sida från fil</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplicera dokument %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 kopierad</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Ta bort sida</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Ta bort dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Är du säker på att du vill ta bort dokument &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Töm papperskorgen</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Är du säker på att du vill tömma papperskorgen?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Tömmer papperskorgen</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Papperskorgen tömd</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Tabort mapp</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Är du säker på att du vill ta bort mapp &apos;%1&apos; och all dess innehåll?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Inget dokument markerat!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Öppna filer som stödjes</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Imporeterar fil %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Import av fil misslyckades ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importera amm bilder från mapp</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tömd</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papperskorg</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Öppna dokument</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Lägg till alla bilder till dokument</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>All bilder (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Markeringen innehåller inga bildfiler!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Är du säker på att du vill ta bort mapp %n sida/sidor från det makrerade dokumentet &apos;%1&apos;?</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Foldern innehåller inga bildfiler</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Namnlösa dokument</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>bilder</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objekt</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>All filer som stödjes (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Fil %1 sparad</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Infoga sida %1 av %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import lyckades.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Import av fil %1 lyckades.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importerar fil %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Sida %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Export misslyckades.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Acceptera</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avsluta</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Papperskorg</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 sidor kopierade</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 sidor kopierade</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopierar sida %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopiera)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopierar sida %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 sidor kopierade</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Hämtning av filer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avsluta</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Sida %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Sida %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Varningar unde export dök upp</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export lyckades.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exporter till IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportera som IWB-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export lyckades.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export misslyckades.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Sida</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportera som ABZ fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export lyckades.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exporterar %1 %2 av %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export lyckades.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Export misslyckades.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportera som PDF fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export lyckades.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportera till PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportera som PDF fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export lyckades.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exporterar sida %1 av %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportera till PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Sida</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exporter som nätdata</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exporterar dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export lyckades.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export misslyckades.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportera till Webläsare</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Lägg till sida</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Infoga som bakgrund</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Lägg till bibliotek</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Objektinformation</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Lägg till favoriter</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Dela</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Tillbaka till mapp</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Ta bort från favoriter</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Skapa ny mapp</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Scanna filsystemet igen</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>ImporteradBild</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Ljudspår</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Foton</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animationer</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktiviteter</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Applikationer</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Former</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoriter</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>webbsökning</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papperskorg</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Acceptera</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Ange ett nytt mappnamn</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Laddar</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Synlig på utvidgad skärm</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Synlig på utvidgad skärm</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Gå till innehållskällan</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Infoga som bakgrund</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Skriv Text Här&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Text färg</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Redigerbar</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Nät</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Laddar ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Frusen</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Omforma till verkytg</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Gemensamt filformat</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerar fil %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import av fil %1 misslyckades.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import lyckades.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Import msslyckades.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerar fil %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import lyckades.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import av fil %1 misslyckades.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Bild format (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF import misslyckades.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importerar sida %1 av %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Ett fel inträffade när video publicerades på intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publicering till Intranet pågår %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publicera</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Ange användarnamn och lösenordför &quot;%1&quot; på %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Inlogg till Proxy misslyckades</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL fel:

%1

%2

Vill du ignorera felen för den här värden?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avsluta</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kopiera)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Dokumentarkiv förlust</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Engelska</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ryska</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Tyska</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Franska</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Schweizisk franska</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Start av kodomvadlare misslyckades ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Ingen kodomvandlarare för podcast tillgänglig ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Del %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>på ditt skrivbord ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>i mapp %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast skapad %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Fel vi inspelning av podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Förvalda ljudingång</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Ingen inspelning av ljud</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Stor</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publicera på Internet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publicera på YouTube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>version: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Markören är tryckkänslig</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy inloggning</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Användarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Lösenord:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publicera dokumentet på nätet</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titel:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Beskrivning:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publicera</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Mina filmer</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Generera förhandsgranskning av miniatyrbilder...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniatybil genererad ...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Sida %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Mask</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Linjal</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Kompass</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Gradskiva</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Triangel</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Hela sidan</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Nät</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Dokmentsuppdaterare</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>Filerna kräver en uppdatering.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Sökväg till säkerhetskopiering:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Välj en mapp för säkerhetskopiering</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Uppdateringen av filerna lyckades!
Vänligen starta om programmet för att komma åt uppdaterade dokument.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Ett fel inträffade vid uppdateringen. Filerna har inte påverkats.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultatet av uppdateringen av filerna</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Uppdaterar fil</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Vänligen vänta importprocessen börjar snart ...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Påminn mig senare</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Laddar...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 kallats (metod=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube verifiering misslyckades.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Ett fel inträffade när video laddas upp på YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Uppladdning till YouTube pågår %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Ladda upp</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Bilar &amp; fordon</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Husdjur &amp; djur</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Resor &amp; evenemang</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Spel</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komedi</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Flk &amp; bloggar</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Nyheter &amp; politik</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Underhållning</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>utbildning</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Fixa själv &amp; stil</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Ideellt arbete &amp; aktivism</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Vetenskap &amp; teknologi</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Rensa</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Spara fil</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Hämtningen avbröts: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Ett fel inträffade vid öppna fil: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Felmeddelande: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Nätverksfel: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 kvar</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 av %2 (%3/s) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 av %2 - avbröts</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Hämtning</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Hämtning</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adress</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Tidigre idag</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 objekt</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Ny &amp;Flik</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Kloningsflik</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Stäng flik</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Stäng &amp;Andra flikar</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Uppdatera flik</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Uppdatera alla flikar</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Senaste stängda flikar</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Namnlös)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Inga senaste sökningar</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Senaste sökningar</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Rensa senaste sökningar</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Hämta</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Lägg till aktuellt dokument</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Ett fel inträffade när sidan laddades: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Öppna i ny flik</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicera Podcast på YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Nyckelord</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Användarnamn på YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Lösenord på YouTube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">Öppna Sankoré</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>På ljus bakgrund</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>På mörk bakgrund</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Genomskinlighet</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Linjebredd</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Stark</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pennan är tryckkänslig</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Författare</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-post</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Författare</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Beskrivning</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>version : …</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Grundinställningar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Visa</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Visa sida med extern webläsare</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Startsida:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuellt tangentbord</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Storlek på tangentbordet knappar:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Verktygsfält</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Placerad högst upp (rekommenderas för läsplattor)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Placerad längst ner (rekommenderas för whiteboardtavla)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Visa text under knapp</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Pekpennans palett</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markör</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Uppdatering av mjukvara</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Kontrollera programuppdateringar vid start av programmet</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenser</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Visa innehåll för intern webbsida på den sekundära skärmen eller projektor</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Visa flera</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Byt kontrollskärm och visa skärm</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Läge</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Startläge</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tavla</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivbord</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy användare:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Poäng</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">På mörk bakgrund</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Genomskinlighet</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">På ljus bakgrund</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Lagra flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Välj en flash att lagra</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>om:tom</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Applikationens namn</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Skapa applikation</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
